sample_test_fail_setup_suite_20150111_234906

### sample_config2

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
0 | 0 | 0 | 0 | 2015-01-11 23:49:46 | 2015-01-11 23:49:46 | 0.000244855880737 sec | Report

Messages: setup_suite() failed. See below for the trace. Traceback (most recent call last): File "/Users/jehrlich/workspace/zopkio/zopkio/test_runner.py", line 107, in run self.deployment_module.setup_suite() File "/Users/jehrlich/workspace/zopkio/test/samples/sample_test_fail_setup_suite.py", line 38, in setup_suite raise ValueError("Random exception") ValueError: Random exception